# README #

How to use? Even I don't know man. Find out for yourself

### What is this repository for? ###

* Extracting coordinates from maps and weather query
* 0.0.1
* [Learn Markdown](https://bitbucket.org/tutorials/markdowndemo)

### How do I get set up? ###

* Pretty straight forward setup pip install package_name
* No need of deployment

### Contribution guidelines ###

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* https://github.com/phantom791
* https://instagram.com/hereyndnow